@@ -14,9 +14,13 @@ ipmranger=function (marbolr, da, ntree)
     for (j in 1:length(ob)) {
       da1 = da[ob[j], ]
       wv = prevtree(ar, da1)
+			if (is.null(wv)){totob[ob[j]]=totob[ob[j]]-1}
+		else{
+
       pupi = table(wv)/length(wv)
       dond = unique(sort(wv))
       pup[ob[j], dond] = pup[ob[j], dond] + as.numeric(pupi)
+			}
     }
   }
   pupf = pup
